from MindMapBBS import MindMapBBS
from MindMapBBS import manage_addMindMapBBSForm, manage_addMindMapBBS
from ImageFile import ImageFile

def initialize(registrar):
    registrar.registerClass(
        MindMapBBS,
        constructors = (manage_addMindMapBBSForm, manage_addMindMapBBS),
        icon='www/icon.png',
    )

misc_ = {
    "add":     ImageFile('www/add.png', globals()),
    "change":  ImageFile('www/change.png', globals()),
    "forward": ImageFile('www/forward.png', globals()),
    "back":    ImageFile('www/back.png', globals()),
    "up":      ImageFile('www/up.png', globals()),
    "down":    ImageFile('www/down.png', globals()),
    "newmmb":  ImageFile('www/newmmb.png', globals()),
    "link":    ImageFile('www/link.png', globals()),
    "mmbLink": ImageFile('www/mmbLink.png', globals()),
    }
